@@ -17,6 +17,14 @@ def compare_simple(x, y, context):
     """
     Returns a very simple textual difference between the two supplied objects.
     """
+    if context.ignore_eq:
+        try:
+            hash_eq = hash(x) == hash(y)
+        except TypeError:
+            pass
+        else:
+            if hash_eq:
+                return
     return context.label('x', repr(x)) + ' != ' + context.label('y', repr(y))
 
 
@@ -73,7 +81,7 @@ def compare_generator(x, y, context):
     x = tuple(x)
     y = tuple(y)
 
-    if x == y:
+    if not context.ignore_eq and x == y:
         return
 
     return compare_sequence(x, y, context)
@@ -311,6 +319,7 @@ class CompareContext(object):
 
         self.recursive = options.pop('recursive', True)
         self.strict = options.pop('strict', False)
+        self.ignore_eq = options.pop('ignore_eq', False)
 
         if 'expected' in options or 'actual' in options:
             self.x_label = 'expected'
@@ -380,7 +389,7 @@ class CompareContext(object):
         current_message = ''
         try:
 
-            if not self.strict and x == y:
+            if not (self.strict or self.ignore_eq) and x == y:
                 return False
 
             comparer = self._lookup(x, y)
@@ -441,6 +450,12 @@ def compare(*args, **kw):
     :param strict: If ``True``, objects will only compare equal if they are
                    of the same type as well as being equal.
 
+    :param ignore_eq: If ``True``, object equality, which relies on ``__eq__``
+                      being correctly implemented, will not be used.
+                      Instead, comparers will be looked up and used
+                      and, if no suitable comparer is found, objects will
+                      be considered equal if their hash is equal.
+
     :param comparers: If supplied, should be a dictionary mapping
                       types to comparer functions for those types. These will
                       be added to the global comparer registry for the duration
